<!-- # acados -->

![](docs/_static/acados_logo.png)
<!-- [![Travis Status](https://secure.travis-ci.org/acados/acados.png?branch=master)](http://travis-ci.org/acados/acados) -->
[![Appveyor status](https://ci.appveyor.com/api/projects/status/q0b2nohk476u5clg?svg=true)](https://ci.appveyor.com/project/roversch/acados)
![Github actions full build workflow](https://github.com/acados/acados/actions/workflows/full_build.yml/badge.svg)
<!-- [![codecov](https://codecov.io/gh/acados/acados/branch/master/graph/badge.svg)](https://codecov.io/gh/acados/acados) -->

`acados` provides fast and embedded solvers for nonlinear optimal control.
It is written in `C` and offers interfaces to the programming languages `Python`, `MATLAB` and `Octave`.

## General
- `acados` implements
  1. fast SQP-type solvers for Nonlinear Programming (NLP) formulations with an Optimal Control Problem (OCP) structure
  2. efficient integration methods, also called *integrators*, to solve initial value problems with dynamic systems given as an ODE or index-1 DAE.
  These integrators can efficiently compute first and second-order sensitivities of the results.

## Documentation
- Documentation can be found on [docs.acados.org](https://docs.acados.org/)
- An overview of the interfaces can be found at [docs.acados.org/interfaces](https://docs.acados.org/interfaces)

## Forum
- If you have any `acados`-related questions, feel free to post on our forum at [discourse.acados.org](https://discourse.acados.org/)

## Citing
- References can be found at [docs.acados.org/citing](https://docs.acados.org/citing)

## Installation
- Instructions can be found at
[docs.acados.org/installation](https://docs.acados.org/installation)
